@@ -8,14 +8,14 @@
 #   The (three-clause) BSD License
 #
 package ElasticSearchX::Model::Document::Types;
-$ElasticSearchX::Model::Document::Types::VERSION = '1.0.1';
+$ElasticSearchX::Model::Document::Types::VERSION = '1.0.2';
 use List::MoreUtils ();
 use DateTime::Format::Epoch::Unix;
 use DateTime::Format::ISO8601;
 use MooseX::Attribute::Deflator;
 use MooseX::Attribute::Deflator::Moose;
 use DateTime;
-use JSON;
+use JSON::MaybeXS qw( decode_json encode_json );
 use Scalar::Util qw(blessed);
 use MooseX::Types::ElasticSearch qw(:all);
 
@@ -191,7 +191,7 @@ ElasticSearchX::Model::Document::Types
 
 =head1 VERSION
 
-version 1.0.1
+version 1.0.2
 
 =head1 AUTHOR
 
